library(psych) # useful for summary stats
library(kableExtra) # creates nice tables
library(survival)

df <- read.csv("D:/COURSES I HAVE RUN/Survival Analysis NCRM/capaldi_example_pres_n2/capaldimod.csv")
# Table of data
df %>%
  kbl() %>%
  kable_styling()

### describe the dataset
describe(df[ , c("time", "censor", "pt", "pas")])

#the event is  not_censor, i.e. event when censor did not take place
df$event <- ifelse(df$censor == 1, 0, 1)
table (df$event, df$censor)

####***************************************************************
####***************************************************************
### Life Table ####
####***************************************************************

# Create a survival object
surv_obj <- Surv(time = df$time, event = df$event)

# Generate the life table
life_table <- survfit(surv_obj ~ 1, data = df)

# Extract the number of censored cases
censored_cases <- life_table$n.censor

# Calculate the hazard function
hazard_function <- life_table$n.event / life_table$n.risk

# Combine the results into a data frame
lt <- data.frame(
  time = life_table$time,
  n.risk = life_table$n.risk,
  n.event = life_table$n.event,
  n.censor = censored_cases,
  survival = round(life_table$surv, 3),
  hazard = round(hazard_function, 3)
)

# Display the life table with hazard function
# Create the table
lt %>%
  kbl() %>%
  kable_classic_2(full_width = F)


library(survival)
library(ggplot2)
library(survminer)
library("ggsci")
library("ggthemes")

# Create a data frame for plotting
plot_data <- data.frame(
  time = lt$time,
  hazard = lt$hazard
)

####***************************************************************
####***************************************************************
### Hazard Function Plot ####
####***************************************************************

# Plot the discrete time hazard function with color palette
ggplot(plot_data, aes(x = time, y = hazard)) +
  geom_line(size=3, col="brown") +
  labs(title = "Discrete Time Hazard Function",
       x = "Time",
       y = "Hazard Function") +
  ylim(c(0,.5)) +
  theme_economist() 


####***************************************************************
####***************************************************************
### Survivor FUnction Plot ####
####***************************************************************

# Extract the summary to get the survival function
surv_summary <- summary(life_table)

# Create the survival function data frame
surv_df <- data.frame(
  time = surv_summary$time,
  surv = surv_summary$surv
)

# Calculate the median lifetime
median_lifetime <- life_table$time[which.min(abs(life_table$surv - 0.5))]

# Plot the survivor function
ggplot(surv_df, aes(x = time, y = surv)) +
  ylim(c(0,1)) +
  geom_line(size=3, col="brown") +
  geom_vline(xintercept = median_lifetime, linetype = "dashed", color = "navy") +
  labs(title = "Survivor Function", x = "Time", y = "Survival Probability") +
  annotate("text", x = median_lifetime, y = 0.5, 
           label = paste("Median: 11.01"), vjust = -1, color = "navy") +
  theme_economist() 
  

