library(psych) # useful for summary stats
library(kableExtra) # creates nice tables
library(survival)

df <- read.csv("D:/COURSES I HAVE RUN/Survival Analysis NCRM/capaldi_example_pres_n2/capaldimod.csv")

#drop the X var which indicates order of cases
df <- subset(df, select = -c(X))

# Table of data
df %>%
  kbl() %>%
  kable_styling()



### describe the dataset
describe(df[ , c("time", "censor", "pt", "pas")])

#the event is  not_censor, i.e. event when censor did not take place
df$event <- ifelse(df$censor == 1, 0, 1)
table (df$event, df$censor)


#table of PT covariate
table(df$pt)

####***********************************************************************************************************
#### Life tables for PT covariate ####
####***********************************************************************************************************

ts0 <- survfit( Surv(time, event)~ 1, conf.type="none", subset=(pt==0), data=df)
ts1 <- survfit( Surv(time, event)~ 1, conf.type="none", subset=(pt==1), data=df)

h0<-ts0$n.event/ts0$n.risk
h1<-ts1$n.event/ts1$n.risk

tab3.0<-cbind(time=ts0$time, n.risk=ts0$n.risk, 
              n.event=ts0$n.event, n.censor=ts0$n.censor, 
              hazard=round(h0, 3), survival=round(ts0$surv, 3))
tab3.1<-cbind(time=ts1$time, n.risk=ts1$n.risk, 
              n.event=ts1$n.event, n.censor=ts1$n.censor, 
              hazard=round(h1,3),  survival=round(ts1$surv, 3))

# Display the life table with hazard function
tab3.0 %>%
  kbl() %>%
  kable_classic_2(full_width = F)

tab3.1 %>%
  kbl() %>%
  kable_classic_2(full_width = F)


####***********************************************************************************************************
#### Plot Hazard Functions ####
####***********************************************************************************************************


library(survival) # to create survival objects and surival estimates
library(ggplot2) # to create plots
library("ggthemes") #to use pre-sets in graphs editing
library(RColorBrewer) #to use pre-set colour palettes
library(dplyr) # to run data manipulations, e.g. select subsets

# create data frames instead of just binding
tab3.0<-data.frame(time=ts0$time, n.risk=ts0$n.risk, 
              n.event=ts0$n.event, n.censor=ts0$n.censor, 
              hazard=round(h0, 3), survival=round(ts0$surv, 3))
tab3.1<-data.frame(time=ts1$time, n.risk=ts1$n.risk, 
              n.event=ts1$n.event, n.censor=ts0$n.censor, 
              hazard=round(h1,3),  survival=round(ts1$surv, 3))



#select the values I need for the plots
st30<-select(tab3.0, c("time", "hazard"))
st31<-select(tab3.1, c("time", "hazard"))

# Append values
tpt<-rbind(st30, st31)
#create indicator for pt
tpt$pt <- c(rep(0, 6), rep(1, 6))



# Create a data frame for plotting pt==0
hf_pt <- data.frame(
  time = tpt$time,
  hazard = tpt$hazard, 
  pt=tpt$pt
)



# Plot the discrete time hazard function with color palette
ghf_pt<-ggplot(hf_pt, aes(x = time, y = hazard, color = factor(pt))) +
  geom_line(linewidth=3 ) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
  #scale_color_brewer(palette="Paired",labels = c("No", "Yes")) + # Not used here, I opted for manually assigned colours above
  labs(title = "Hazard Function",
       x = "Time",
       y = "Hazard Function", 
       color = "Parental Transition") +
  ylim(c(0,.5)) +
  theme_hc() 

ghf_pt


####***********************************************************************************************************
#### Plot Survivor Functions ####
####***********************************************************************************************************


# Create the survival function data frame
#select the values I need for the plots
vs31<-select(tab3.0, c("time", "survival"))
vs32<-select(tab3.1, c("time", "survival"))


# Append values from the selection before
vsall<-rbind(vs31, vs32)
#create indicator for pt -
vsall$pt <- c(rep(0, 6), rep(1, 6))



# Create a data frame for plotting 
df_survpt <- data.frame(
  time = vsall$time,
  survival = vsall$survival, 
  pt=vsall$pt
)


# Plot the survivor function
survpt<-ggplot(df_survpt, aes(x = time, y = survival, color = factor(pt))) +
  ylim(c(0,1)) +
  geom_line(size=3) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
 # scale_color_brewer(palette="Set2",labels = c("No", "Yes")) + # Not used here, I opted for manually assigned colours above
  labs(title = "Survivor Function",
       x = "Time",
       y = "Survival Prob.", 
       color = "Parental Transitiion") +
  theme_hc() 


survpt


####***************************************************************
####***************************************************************
###  Tertile Lifetime ####
####***************************************************************

#************************************************* PT=0
# Extract survival probabilities and times
surv_probs1 <- summary(ts0)$surv
surv_times1 <- summary(ts0)$time

# Find the time points around the median survival probability (0.5)
lower_index1 <- max(which(surv_probs1 >= 0.67))
upper_index1 <- min(which(surv_probs1 < 0.67))

# Linear interpolation to find the median lifetime
tert_lifetime1 <- surv_times1[lower_index1] + 
  (0.67 - surv_probs1[lower_index1]) * 
  (surv_times1[upper_index1] - surv_times1[lower_index1]) / 
  (surv_probs1[upper_index1] - surv_probs1[lower_index1])

# Print the median lifetime
print(tert_lifetime1)

#************************************************ PT ==1 
#*# Extract survival probabilities and times
surv_probs2 <- summary(ts1)$surv
surv_times2 <- summary(ts1)$time

# Find the time points around the median survival probability (0.5)
lower_index2 <- max(which(surv_probs2 >= 0.67))
upper_index2 <- min(which(surv_probs2 < 0.67))

# Linear interpolation to find the median lifetime
tert_lifetime2 <- surv_times2[lower_index2] + 
  (0.67 - surv_probs2[lower_index2]) * 
  (surv_times2[upper_index2] - surv_times2[lower_index2]) / 
  (surv_probs2[upper_index2] - surv_probs2[lower_index2])

# Print the median lifetime
print(tert_lifetime2)


####***************************************************************
####***************************************************************
### Survival function plot  with tertile lifetimes ####
####***************************************************************

#define the colours:
colours<-c("#EEA236", "#357EBD")

####*
tert_lifetimes <- data.frame(pt = c("No", "Yes"),
tert_lifetime = c(9.28, 10.77) 
)
# Add annotations for each  group
for (i in 1:nrow(tert_lifetimes)) {
  survpt <- survpt +
    geom_vline(xintercept = tert_lifetimes$tert_lifetime[i], linetype = "dashed", color = colours[i]) +
    annotate("text", x = tert_lifetimes$tert_lifetime[i], y = 0.5, 
             label = paste("", tert_lifetimes$tert_lifetime[i]), 
             vjust = tert_lifetimes$tert_lifetime[i], color =colours[i])
}

# Print the plot
print(survpt) +
  geom_hline(yintercept = 0.67, linetype = "dashed", color = "black") +
  annotate("text", x = max(hf_pt$time), 
           y = 0.67, label = "0.67", vjust = -1, hjust = 1, color = "black")


####***************************************************************
####***************************************************************
### Odds trans ####
####***************************************************************
ghf_pt1<-ghf_pt+   ylim(c(0,1))  #display bounded prob
ghf_pt1

# odds transformation
hf_pt$oddsh<-hf_pt$hazard/(1-hf_pt$hazard)




# Plot the discrete time hazard function with color palette
ghf_pt2<-ggplot(hf_pt, aes(x = time, y = oddsh, color = factor(pt))) +
  geom_line(size=3 ) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
  #scale_color_brewer(palette="Paired",labels = c("No", "Yes")) + # Not used here, I opted for manually assigned colours above
  labs(title = "Odds of Hazard Function",
       x = "Time",
       y = "Odds of Event", 
       color = "Parental Transition") +
  ylim(c(0,1)) +
  theme_hc() 

ghf_pt2


####***************************************************************
####***************************************************************
### Logit ####
####***************************************************************

# logits  transformation
hf_pt$logith<-log(hf_pt$oddsh) #the natural log of the odds ratios




# Plot the discrete time hazard function with color palette
ghf_pt3<-ggplot(hf_pt, aes(x = time, y = logith, color = factor(pt))) +
  geom_line(size=3 ) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
  #scale_color_brewer(palette="Paired",labels = c("No", "Yes")) + # Not used here, I opted for manually assigned colours above
  labs(title = "Logits of Hazard Function",
       x = "Time",
       y = "Odds of Event", 
       color = "Parental Transition") +
  ylim(-4, 0) +
    theme_hc() 

ghf_pt3

####***************************************************************
####***************************************************************
### Arrange the plots in one figure ####
####***************************************************************

library(ggpubr) #allows to arrange plots together
figure <- ggarrange(ghf_pt1, ghf_pt2, ghf_pt3, 
                    ncol = 2, nrow = 2, common.legend = TRUE, legend="top")
figure

####***************************************************************
####***************************************************************
### Restructure data to Person-Period  ####
####***************************************************************
library(tidyverse) # to manipulate dataset


# Function to create person-period data
create_person_period <- function(data) {
  data %>%
    rowwise() %>%
    mutate(periods = list(7:time)) %>%
    unnest(periods) %>%
    mutate(event = ifelse(periods == time & event == 1, 1, 0),
           censor = ifelse(periods == time & censor == 1, 1, 0)) %>%
    filter(periods <= time) %>%
    select(id, periods, event, censor, pt, pas)
}


#Explanation:
# 1.mutate(periods = list(1:time)):
#This creates a list of periods from 7 to the event time or censoring time.
#2.unnest(periods):
# This expands the list of periods into individual rows.
#3.mutate(event = ifelse(periods == time & event == 1, 1, 0), 
#censor = ifelse(periods == time & censor == 1, 1, 0)):
# This ensures that the event and censor columns are correctly marked 
#only for the period when the event or censoring occurs.
#4. filter(periods <= time):
#This filters out any periods beyond the event or censoring time, 
#ensuring that individuals only contribute periods up to the event or censoring time.
#This should ensure that each individual only contributes periods up to 
#the event or censoring time, and no additional periods are included.

# Apply the function to the dataset
ppdf <- create_person_period(df)

write.csv(ppdf, file="D:\\COURSES I HAVE RUN\\Survival Analysis NCRM\\capaldi_example_pres_n2\\ppdf.csv", row.names = FALSE)


# Table of data
ppdf %>%
  kbl() %>%
  kable_styling()




####***************************************************************
####***************************************************************
### Estimate and plot model A (Baseline) ####
####***************************************************************
##*** estimate baseline model 

modelA<-glm(event~factor(periods) - 1, family="binomial", data=ppdf)
summary(modelA)

ghf_pt3



# Create a data frame for the new line
baseline <- data.frame(
  time = c(7:12),
  value = c(-2.3979, -3.116, -2.0513, -1.4240, -1.3863, -1.0330))

# Plot the line
gbasel<-ggplot(baseline, aes(x = time, y = value)) +
  geom_line(color = "#357EBD", size = 3, linetype = "longdash") +
  labs(title = "Fitted Logit Hazard Functions: Baseline",
       x = "Time",
       y = "Fitted values") +
  ylim(c(-4,0)) +
  theme_hc() 

gbasel



####***************************************************************
####***************************************************************
### model B: Covariate PT ####
####***************************************************************


modelB<-glm(event~factor(periods) + pt - 1, family="binomial", data=ppdf)
summary(modelB)


#create summaries for plotting
t<-data.frame(hazard=modelB$fitted.values, time=ppdf$periods, pt=ppdf$pt)
t$logit<-log(t$hazard/(1-t$hazard))

ta<-aggregate(t, list(pt=t$pt, time=t$time),mean)
ta.0<-ta[ta$pt==0, ]
ta.1<-ta[ta$pt==1, ]



####***************************************************************
####***************************************************************
### Plot the two lines
####***************************************************************

# Create a data frame for the new line


baseline<-select(ta.0, c("time", "logit", "pt"))
covariate<-select(ta.1, c("time", "logit", "pt"))
dfmodB<-rbind(baseline, covariate)

# Plot the lines


# Plot the discrete time hazard function with color palette
gmodB<-ggplot(dfmodB, aes(x = time, y = logit, color = factor(pt))) +
  geom_line(size=3 ) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
  #scale_color_brewer(palette="Paired",labels = c("No", "Yes")) + # Not used here, I opted for manually assigned colours above
  labs(title = "Estimated Logits of Hazard Function",
       x = "Time",
       y = "Estimted Values", 
       color = "Parental Transition") +
  ylim(-4, 0) +
  theme_hc() 

gmodB



####***************************************************************
####***************************************************************
### Plot the model in different metrics --> Odds and Hazard (prob.) 
####***************************************************************

print(dfmodB) 

# dfmodB is the data frame with the logits estimated in model B
# I will use transformations to get the odds and the hazard function in probability scale

dfmodB$odds<-exp(dfmodB$logit)
dfmodB$hf<-1/(1+exp(-dfmodB$logit))



# Plot the odds
gmodBodds<-ggplot(dfmodB, aes(x = time, y = odds, color = factor(pt))) +
  geom_line(size=3 ) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
  labs(title = "Estimated Odds of Hazard Function",
       x = "Time",
       y = "Estimated Values", 
       color = "Parental Transition") +
  ylim(0, .6) +
  theme_hc() 

gmodBodds


# Plot the Hazard esimtates
gmodBhf<-ggplot(dfmodB, aes(x = time, y = hf, color = factor(pt))) +
  geom_line(size=3 ) +
  scale_color_manual(values = c("#357EBD", "#EEA236"), labels = c("No", "Yes")) +
  labs(title = "Estimated Hazard Function",
       x = "Time",
       y = "Estimated Values", 
       color = "Parental Transition") +
  ylim(0, .4) +
  theme_hc() 

gmodBhf

