# Load necessary libraries
library(ggplot2)
library(RColorBrewer)

# Create the data frame
data <- data.frame(
  Participant = factor(c(1, 2, 3, 4, 5)),
  Start_Age = c(14, 14, 14, 14, 14),
  End_Age = c(17, 25, 15, 31, 20),
  Event = c("Suicidal Thoughts", "Suicidal Thoughts", "Suicidal Thoughts", "Left Study", "Left Study")
)

labpar<-c("#1", "#2", "#3", "#4", "#5")


# Create the plot
ggplot(data, aes(x = Start_Age, xend = End_Age, y = Participant, yend = Participant, color = Participant)) +
  geom_segment(size = 2) +  # Thicker lines
  geom_point(aes(x = End_Age, y = Participant, shape = Event), size = 7, color = "black") +  # Black markers
  scale_color_brewer(palette = "Paired") +  # Use color palette
  scale_shape_manual(values = c("Suicidal Thoughts" = 16, "Left Study" = 4)) +  # Different shapes for markers (X for censoring)
  labs(title = "Onset of Suicidal Thoughts", x = "Age", y = "Participants") +
  theme_minimal() +
 # theme(panel.grid = element_blank()) +  # Remove grid
  scale_y_discrete(label = labpar) +  # Set y-axis ticks to integers only
  guides(color = "none", shape = guide_legend("Legend: ")) +  # Remove legend for participants, add legend for markers
  theme(legend.position = "bottom", legend.box.margin = margin(t = 10))  # Position legend at the bottom with margin