# Load necessary libraries
library(ggplot2)
library(RColorBrewer)

# Create the data frame
d1 <- data.frame(
  Participant = factor(c(1, 2, 3, 4, 5)),
  Start_Age = c(0, 0, 0, 0, 0),
  End_Age = c(3, 2.5, 3, 2.3, 1.9),
  Event = c("", "Event", "", "Event", "Event")
)

labpar<-c("#1", "#2", "#3", "#4", "#5")


# Create the plot
ggplot(d1, aes(x = Start_Age, xend = End_Age, y = Participant, yend = Participant, color = Participant)) +
  geom_segment(size = 2) +  # Thicker lines
  geom_point(aes(x = End_Age, y = Participant, shape = Event), size = 7, color = "black") +  # Black markers
  scale_color_brewer(palette = "Set2") +  # Use color palette
  scale_shape_manual(values = c("Event" = 16, "#" = 4)) +  # Different shapes for markers (X for censoring)
  labs(title = "Clock starts at the same time (birth)", x = "Age", y = "Participants") +
  theme_minimal() +
  # theme(panel.grid = element_blank()) +  # Remove grid
  scale_y_discrete(label = labpar) +  # Set y-axis ticks to integers only
  guides(color = "none", shape = guide_legend("Legend: ")) +  # Remove legend for participants, add legend for markers
  theme(legend.position = "bottom", legend.box.margin = margin(t = 10))  # Position legend at the bottom with margin



# Create the data frame
d2 <- data.frame(
  Participant = factor(c(1, 2, 3, 4, 5)),
  Start_Age = c(25, 18, 22, 19, 21),
  End_Age = c(36, 22, 29, 36, 33),
  Event = c("", "Event", "Event", "", "Event")
)

labpar<-c("#1", "#2", "#3", "#4", "#5")


# Create the plot
ggplot(d2, aes(x = Start_Age, xend = End_Age, y = Participant, yend = Participant, color = Participant)) +
  geom_segment(size = 2) +  # Thicker lines
  geom_point(aes(x = End_Age, y = Participant, shape = Event), size = 7, color = "black") +  # Black markers
  scale_color_brewer(palette = "Dark2") +  # Use color palette
  scale_shape_manual(values = c("Event" = 16, "#" = 4)) +  # Different shapes for markers (X for censoring)
  labs(title = "Clock starts with precipitating event (start employment)", x = "Age", y = "Participants") +
  theme_minimal() +
  # theme(panel.grid = element_blank()) +  # Remove grid
  scale_y_discrete(label = labpar) +  # Set y-axis ticks to integers only
  guides(color = "none", shape = guide_legend("Legend: ")) +  # Remove legend for participants, add legend for markers
  theme(legend.position = "bottom", legend.box.margin = margin(t = 10))  # Position legend at the bottom with margin